import typer
from wssiham.core.indicateur.indicateur import Indicateur
from wssiham.tools.typerExtend import TyperExtend
from rich.progress import Progress, SpinnerColumn, TextColumn, TimeElapsedColumn

import logging

logger = logging.getLogger(__name__)
app = typer.Typer()


def temoin_callback(value: str) -> int:
    return 1 if value else 0


@app.command()
def nbpersuo(uo: str = typer.Argument(..., help="Code UO recherché."),
             date: str = typer.Option("", "--date", "-d", help="Date d'observation."),
             temoin: bool = typer.Option(False, "--temoin", "-t",
                                         help="Témoin UO fille.")):
    """ Récupère le nombre de personnes qui sont affectés dans une UO.
    L'UO est obligatoire.
    """

    TyperExtend.simple_echo(f'Préparation de la récupération du nombre d\'agents dans l\'UO {uo}')
    with Progress(
        SpinnerColumn(),
        TextColumn("[progress.description]{task.description}"),
        TimeElapsedColumn(),
        transient=False,
    ) as progress:
        progress.add_task(description="Récupération des données via le web service SIHAM ...",
                          total=None)

        indicateur = Indicateur(code_uo_affectation=uo, date_observation=date, temoin_uo_fille=temoin)

        result = indicateur.response()
    if result >= 0:
        TyperExtend.valid_echo("L'opération a été effectuée avec succès")
        TyperExtend.simple_echo(f"{indicateur.param_indicateur()}")
        TyperExtend.simple_echo(f"Nombre individus pour l'UO {uo} : {result}")
    else:
        TyperExtend.error_echo("L'opération a été interrompu")
        TyperExtend.exit_unsuccess()

@app.callback()
def main() -> None:
    """Extraction divers indicateurs"""
    pass