from wssiham.tools.xconfig import Xconfig
from wssiham.tools.configuration import Configuration

from base64 import urlsafe_b64decode as b64d
from typing import Optional
from dataclasses import dataclass, field
from requests.auth import HTTPBasicAuth
import zeep
import requests
import zlib


@dataclass
class Zeepclient:
    zeep_client: zeep.client.Client = field(init=False, repr=False)

    def __post_init__(self):
        self.zeep_client = self._init_ws_connection()

    def _init_ws_connection(self) -> zeep.Client:
        """Connection au webservice SIHAM
        """
        config = Configuration.loadws()
        user = config.get('USER')
        pwd: Optional[str] = zlib.decompress(b64d(config.get('PASSWORD'))).decode('utf-8')
        wsdl = f"{config.get('BASE_WSDL')}{config.get(self.__class__.__module__.split('.')[2].upper())}"
        certificat: Optional[str] = config.get('CERTIFICAT')

        session = requests.Session()
        session.auth = HTTPBasicAuth(user, pwd)
        session.verify = f"{Xconfig.dirconfile}/{certificat}" if certificat else True

        return zeep.Client(wsdl, transport=zeep.transports.Transport(session=session))




