from dataclasses import dataclass, field
from typing import Dict, Union
from wssiham.connection.zeepclient import Zeepclient
from wssiham.tools.mdate import Mdate
import zeep
import logging


logger = logging.getLogger(__name__)


@dataclass
class ModifAffectationSecondaire(Zeepclient):
    """Ce flux est mis en place pour permettre à des applications gérant le dossier du personnel de pouvoir apporter
    des modifications au niveau de SIHAM. Il donne la possibilité d’ajouter ou de supprimer une affectation secondaire
    disposant de tout type de rattachement
    """
    matricule: str
    code_uo_affect_adresse: str = field(default='')
    date_debut: str = field(default='')
    date_fin: str = field(default='')
    pourcentage_affectation: Union[int, None] = field(default=None)
    temoin_validite: str = field(default='')
    type_action: str = field(default='')                            # A : Ajout, S : Suppression, M : Modification
    type_rattachement: str = field(default='')

    def response(self) -> str:
        """ Retourne le statut de la mise à jour "StatutMaj"
        - 1 : OK
        - 2 : KO

        Returns:
            Le statut de la mise à jour de l'affectation secondaire de l'agent
        """
        result = -1
        try:
            resp = self.zeep_client.service.ModifAffectationSecondaire(
                ParamMAS=self.param_mas())
            if resp:
                result = zeep.helpers.serialize_object(resp)
                logger.debug(result)
        except zeep.exceptions.Fault as fault:
            logger.error(fault)
        return result

    def param_mas(self) -> Dict[str, str]:

        date_debut = Mdate.string_to_datetime(self.date_debut) if self.date_debut else self.date_debut
        date_fin = Mdate.string_to_datetime(self.date_fin) if self.date_fin else self.date_fin

        parammas = {'codeUOAffectAdresse': self.code_uo_affect_adresse,
                    'dateDebut': date_debut,
                    'dateFin': date_fin,
                    'matricule': self.matricule,
                    'pourcentageAffectation': self.pourcentage_affectation,
                    'temoinValidite': self.temoin_validite,
                    'typeAction': self.type_action,
                    'typeRattachement': self.type_rattachement}

        return parammas