from dataclasses import dataclass, field
from typing import List, Optional
from wssiham.connection.zeepclient import Zeepclient
from wssiham.model.response.dossier_agent.recupDonneesDeServiceResponse import InformationService
from wssiham.model.parametre.agent import ParamMatricule
from datetime import datetime

import zeep
import logging


logger = logging.getLogger(__name__)


@dataclass
class RecupDonneesDeService(Zeepclient):
    """ L’objectif de ce flux est de consulter les informations de décharge de service de la population SIHAM
    qui rentre dans les critères.
    """
    liste_matricules: Optional[List[ParamMatricule]] = field(default='')

    code_etablissement: str = field(default='')            # exemple : universite de la reunion = 9740478B
    date_observation: datetime = field(default='')         # format YYYY-MM-DD-HH.MM.SS
    date_fin_observation: datetime = field(default='')     # format YYYY-MM-DD-HH.MM.SS

    def response(self) -> List[Optional[InformationService]]:
        """ Récupere les données de décharge de service de l'agent

        Returns:
            Liste contenant les informations administratives de l'agent recherché
                - Matricule de l’agent
                - Code UAI de l’établissement
                - Libellé court de l’établissement
                - Libellé long de l’établissement
                - Type de décharge
                - Libellé long du type de décharge
                - Nombre d’heures

        """
        result = None
        try:
            resp = \
                self.zeep_client.service.RecupDonneesDeService(ParamDonneesService=
                                                              {'codeEtablissement': self.code_etablissement,
                                                               'dateFinObservation': self.date_fin_observation,
                                                               'dateObservation': self.date_observation,
                                                               'listeMatricules': self.liste_matricules})
            if resp:
                tmp_data = zeep.helpers.serialize_object(resp)
                result = InformationService(**tmp_data[0])
                logger.debug(result)
        except zeep.exceptions.Fault as fault:
            logger.error(fault)
        return result

