from dataclasses import dataclass, field
from typing import List, Optional
from wssiham.connection.zeepclient import Zeepclient
from wssiham.model.response.dossier_agent.recupProchainEchelonReponse import InformationProchainEchelon
from wssiham.model.parametre.agent import ParamMatricule
from datetime import datetime

import zeep
import logging


logger = logging.getLogger(__name__)


@dataclass
class RecupProchainEchelon(Zeepclient):
    """SIHAM permet de simuler l’avancement d’échelon des agents. Cette information peut être exposée, via ce flux,
    aux applications externes. Il est possible de consulter les données d’avancement d’échelon pour un ou plusieurs
    agents en fonction d’une date d’observation.
    """
    liste_matricules: List[ParamMatricule]

    code_etablissement: str = field(default='')                 # exemple : universite de la reunion = 9740478B
    date_observation: datetime = field(default='')       # format YYYY-MM-DD-HH.MM.SS
    date_fin_observation: datetime = field(default='')               # format YYYY-MM-DD-HH.MM.SS

    def response(self) -> Optional[List[Optional[InformationProchainEchelon]]]:
        """ Récupere les données d'avancement d'échelon
        """
        result = None
        try:
            resp = \
                self.zeep_client.service.RecupProchainEchelon(ParamListAgent=
                                                              {'codeEtablissement': self.code_etablissement,
                                                               'dateFinObservation': self.date_fin_observation,
                                                               'dateObservation': self.date_observation,
                                                               'listeMatricules': self.liste_matricules})
            if resp:
                tmp_data = zeep.helpers.serialize_object(resp)
                result = InformationProchainEchelon(prochainEchelon=tmp_data)
                logger.debug(result)
        except zeep.exceptions.Fault as fault:
            logger.error(fault)
        return result


