from dataclasses import dataclass, field
from typing import List, Optional
from wssiham.connection.zeepclient import Zeepclient
from wssiham.model.response.dossier_agent.recupTableauAvancementResponse import InformationTableauAvancement
from wssiham.model.parametre.agent import ParamMatricule
from datetime import datetime

import zeep
import logging


logger = logging.getLogger(__name__)


@dataclass
class RecupTableauAvancement(Zeepclient):
    """Cette opération permet d’envoyer les informations concernant les propositions d’avancement d’un ou
    plusieurs agents, pour les avancements de grade, les promotions internes et les reclassements.
    """
    liste_matricules: List[ParamMatricule]

    code_etablissement: str = field(default='')                 # exemple : universite de la reunion = 9740478B
    date_observation: datetime = field(default='')              # format YYYY-MM-DD-HH.MM.SS
    code_type_avancement: str = field(default='')

    def response(self) -> Optional[InformationTableauAvancement]:
        """ Récupere les données d'avancement d'échelon
        """
        result = None
        try:
            resp = \
                self.zeep_client.service.RecupTableauAvancement(ParamTableauAvancement=
                                                                {'codeEtablissement': self.code_etablissement,
                                                                 'codeTypeAvancement': self.code_type_avancement,
                                                                 'dateObservation': self.date_observation,
                                                                 'listeMatricules': self.liste_matricules})
            if resp:
                tmp_data = zeep.helpers.serialize_object(resp)
                result = InformationTableauAvancement(tableauAvancement=tmp_data)
                logger.debug(result)
        except zeep.exceptions.Fault as fault:
            logger.error(fault)
        return result


