from dataclasses import dataclass, field
from typing import List, Optional
from wssiham.connection.zeepclient import Zeepclient
from wssiham.model.response.dossier_agent_date.recupDonneesAgentsResponse import DonneeAgent
from wssiham.model.parametre.agent import ParamMatricule
from wssiham.tools.mdate import Mdate

import zeep
import logging


logger = logging.getLogger(__name__)


@dataclass
class RecupDonneesAgents(Zeepclient):
    """ Ce Web Service permet d’extraire l’exhaustivité des attributs de l’agent en vigueur ou non à la
    date d’observation.
    """
    liste_matricules: List[ParamMatricule]                                          # matricule de l'agent recherché
    date_observation: str = field(default='')               # format YYYY-MM-DD-HH.MM.SS

    def response(self) -> Optional[List[DonneeAgent]]:
        """ Récupere l’exhaustivité des attributs de l’agent en vigueur ou non à la date d’obervation

        Returns:
            Liste contenant les données personnelles et professionnelles de l'agent


        """
        result = None
        try:
            date_observation = Mdate.string_to_datetime(self.date_observation) if self.date_observation \
                else self.date_observation

            resp = \
                self.zeep_client.service.RecupDonneesAgents(ParamAgentDateWS={'dateObservation': date_observation,
                                                                              'listeMatricules': self.liste_matricules})
            if resp:
                tmp_data = zeep.helpers.serialize_object(resp)
                result = [DonneeAgent(**ele) for ele in tmp_data]
                logger.debug(result)
        except zeep.exceptions.Fault as fault:
            logger.error(fault)
        return result
