from dataclasses import dataclass, field
from typing import List, Union
from wssiham.connection.zeepclient import Zeepclient
from wssiham.model.response.liste_agents.genericAgentsReponse import InformationAgentEcheanceList
from wssiham.tools.mdate import Mdate

import zeep
import logging


logger = logging.getLogger(__name__)


@dataclass
class RecupAgentsEcheance(Zeepclient):
    """Ce Web Service retourne les matricules des agents dont l’un des attributs échangés,
    gérés par date, est entré en vigueur ou arrive à échéance entre les deux dates données en paramètre.
    """

    date_debut_observation: str = field(default='')               # format dd/mm/YYYY
    date_fin_observation: str = field(default='')
    found: tuple[bool, int] = \
        field(init=False, default=(False, -1), repr=False)  # tuple déterminant si un élément a été trouvé et son nombre

    def response(self) -> Union[InformationAgentEcheanceList, List]:
        """ Retourne les codes des structures dont l’un des attributs échangés entre en vigueur ou
         arrive à échéance entre les deux dates données


        Returns:
            Liste contenant les informations concernant le matricule, les témoins et le login Ldap de l'agent.
            (matricule, témoin état de l'agent, témoin retraite, UID)

        """
        result = None
        try:
            date_debut = Mdate.string_to_datetime(self.date_debut_observation) if self.date_debut_observation \
                else self.date_debut_observation

            date_fin = Mdate.string_to_datetime(self.date_fin_observation) if self.date_fin_observation \
                else self.date_fin_observation

            resp = self.zeep_client.service.RecupAgentsEcheance(
                ParamAgentEcheance={'dateDebutObservation': date_debut,
                                    'dateFinObservation': date_fin})

            if resp:
                tmp_data = zeep.helpers.serialize_object(resp)
                result = InformationAgentEcheanceList(information_agent_echeance=tmp_data)
                self.found = (True, len([ele for ele in result.information_agent_echeance]))
            else:
                self.found = (False, 0)
                logger.debug('Aucun élément trouvé')
        except zeep.exceptions.Fault as fault:
            logger.error(fault)
        return result
