from dataclasses import dataclass
from typing import Optional
from wssiham.connection.zeepclient import Zeepclient
from wssiham.model.response.pec.genericPecResponse import GenericPecResponse

import zeep
import logging


logger = logging.getLogger(__name__)


@dataclass
class AnnulationRenouvellement(Zeepclient):
    """Le web service d’annulation de renouvellement permet de supprimer la dernière période renouvelée et de supprimer
    la période générique créée automatiquement par le renouvellement.
    """
    matricule: str

    def response(self) -> Optional[GenericPecResponse]:
        """L’appel du web-service se fait par l’interrogation d’un paramètre qui correspond au matricule de l’agent
        dont on souhaite annuler le renouvellement.

        Returns:
            Le tableau de résultat de l’annulation contient les informations suivantes:
                o	Matricule de l’agent,
                o	Liste des anomalies rencontrées
                o	Statut de l’opération (Qui indique si l’annulation a bien été effectuée).
        """
        result = None
        try:
            resp = self.zeep_client.service.AnnulationRenouvellement(
                ParamAR={'matricule': self.matricule}
            )
            if resp:
                tmp_data = zeep.helpers.serialize_object(resp)
                result = GenericPecResponse(**tmp_data)
                logger.debug(result)
        except zeep.exceptions.Fault as fault:
            logger.error(fault)
        return result
