from dataclasses import dataclass, field
from typing import Optional
from wssiham.connection.zeepclient import Zeepclient
from wssiham.model.response.pec.genericPecResponse import GenericPecResponse

import zeep
import logging
import datetime

logger = logging.getLogger(__name__)


@dataclass
class ModifCoordonneesBancairesPEC(Zeepclient):
    """L’objectif de ce flux est d'ajouter une administration d’origine au dossier de l’agent.
    """

    matricule: str
    cle_compte: str
    code_agence: str
    code_banque: str
    libelle_agence: str
    mode_paiement: str
    num_compte: str
    pays_banque: str
    date_deb_banque: datetime.datetime
    date_fin_banque: datetime.datetime = field(default='')
    iban: str = field(default='')
    swift: str = field(default='')
    temoin_validite: str = field(default='')

    def response(self) -> Optional[GenericPecResponse]:
        """Ce web service permet l’ajout d’une administration d’origine au dossier de l’agent.
        L’appel à ce Web Service se fait par interrogation sur une liste de paramètres
        (matricule, date de début de l’administration d’origine, corps d’origine, etc.).

        Returns:
            Le tableau de résultat de l’annulation contient les informations suivantes:
                o	Matricule de l’agent,
                o	Liste des anomalies rencontrées
                o	Statut de l’opération (Qui indique si l’annulation a bien été effectuée).

        """
        result = None
        try:
            resp = self.zeep_client.service.ModifCoordonneesBancaires(
                ParamMCB={'cleCompte': self.cle_compte,
                          'codeAgence': self.code_agence,
                          'codeBanque': self.code_banque,
                          'dateDebBanque': self.date_deb_banque,
                          'dateFinBanque': self.date_fin_banque,
                          'IBAN': self.iban,
                          'libelleAgence': self.libelle_agence,
                          'matricule': self.matricule,
                          'modePaiement': self.mode_paiement,
                          'numCompte': self.num_compte,
                          'paysBanque': self.pays_banque,
                          'SWIFT': self.swift,
                          'temoinValidite': self.temoin_validite}
            )
            if resp:
                tmp_data = zeep.helpers.serialize_object(resp)
                result = GenericPecResponse(**tmp_data)
                logger.debug(result)
        except zeep.exceptions.Fault as fault:
            logger.error(fault)
        return result
