from dataclasses import dataclass
from typing import Optional
from wssiham.connection.zeepclient import Zeepclient
from wssiham.model.response.pec.genericPecResponse import GenericPecResponse

import zeep
import logging


logger = logging.getLogger(__name__)


@dataclass
class ModificationDatePEC(Zeepclient):
    """L’objectif de ce flux est de modifier la date de prise en charge d’un agent.
    """
    matricule: str
    nouvelle_date: str              # Date au format YYYY-MM-DD

    def response(self) -> Optional[GenericPecResponse]:
        """Le web service modifiera la date de sortie de la période tampon et la date d’entrée de la période suivant
        la prise en charge.
        L’appel à ce Web Service se fait par interrogation sur un paramètre (Matricule) et
        d’une nouvelle date de prise en charge (nouvelleDate).
        Ce flux doit retourner une table contenant les informations tels que,
        le statut de l’opération et la liste des anomalies.

        """
        result = None
        try:
            resp = self.zeep_client.service.ModificationDatePEC(
                ParamMDPEC={'matricule': self.matricule, 'nouvelleDate': self.nouvelle_date}
            )
            if resp:
                tmp_data = zeep.helpers.serialize_object(resp)
                result = GenericPecResponse(**tmp_data)
                logger.debug(result)
        except zeep.exceptions.Fault as fault:
            logger.error(fault)
        return result
