from pydantic import BaseModel
from typing import List, Optional
from wssiham.model.agent.adresse import AdresseDAD
from wssiham.model.agent.affectation import AffectationDAD
from wssiham.model.agent.contact import EmailNumero
from wssiham.model.agent.distinction import Diplome
from wssiham.model.agent.erreur import MatriculeErrone
from wssiham.model.agent.fonction import Fonction, ResponsabiliteHierarchique, FonctionElective
from wssiham.model.agent.informationIndividuel import InformationIndividuelDAD, Nationalite
from wssiham.model.agent.specialite import Specialite


class DonneeAgent(BaseModel):
    """
    Modèle représentant les informations personnelles d'une personne avec ses adresses, affectations, diplômes,
    e-mails, spécialités et nationalités associées.
    """
    donneesPersonnelles: Optional[InformationIndividuelDAD]
    listeAdresses: List[AdresseDAD]
    listeAffectations: List[AffectationDAD]
    listeDiplomes: List[Diplome]
    listeFonctions: Optional[List[Fonction]]
    listeFonctionsElectives: Optional[List[FonctionElective]]
    listeMatriculesErrones: Optional[List[MatriculeErrone]]
    listeNationalites: Optional[List[Nationalite]]
    listeNumerosMails: List[EmailNumero]
    listeResponsabilitesHierarchiq: Optional[List[ResponsabiliteHierarchique]]
    listeSpecialites: List[Specialite]


class DonneeAgentList(BaseModel):
    donneeAgent: List[DonneeAgent]
