from pydantic import BaseModel
from wssiham.model.structure.information import StructureModifie, StructureEcheance
from typing import List

class StructureModifieList(BaseModel):
    """
    Représente une liste de structure modifiée.

    **Attributs**

    * `structure_modifie` : une liste d'instances de la classe `StructureModifie`.

    **Exemple**

    ```python
    information_list = StructureModifieList(
        structure_modifie=[
            StructureModifie(
                codeStructure="XXXXXXXXXXXX",
                typeUO="XXXX"
            ),
            StructureModifie(
                codeStructure="XXXXXXXXXXXX",
                typeUO="XXX"
            )
        ]
    )
    ```
    """

    structure_modifie: List[StructureModifie]


class StructureEcheanceList(BaseModel):
    """
    Représente une liste d'échéance de structure.

    **Attributs**

    * `informations` : une liste d'instances de la classe `StructureEcheance`.

    **Exemple**

    ```python
    information_list = StructureEcheanceList(
        structure_echeance=[
            StructureEcheance(
                codeInformation="XXXXX",
                codeStructure="XXXXXXXXXXXX",
                temEtat="X",
                typeUO="XXXX"
            ),
            StructureEcheance(
                codeInformation="XXXX",
                codeStructure="XXXXXXXXXXXX",
                temEtat="A",
                typeUO="XXX"
            )
        ]
    )
    ```
    """

    structure_echeance: List[StructureEcheance]