from base64 import urlsafe_b64encode as b64e
import zlib
import pathlib
from datetime import datetime
import importlib.metadata


class Utils:

    @staticmethod
    def get_modification_date_file(path: pathlib.Path) -> str:
        """
        Récupère la date de modification d'un fichier sous le format suivant dd/MM/YYYY hh:mm:ss

        Args:
            path (Path): Le chemin vers le fichier

        Returns:
            str: La date de modification sous le format souhaité
        """

        # Obtenez la date de modification du fichier
        modification_date = path.stat().st_mtime

        # Convertissez la date en chaîne
        return datetime.fromtimestamp(modification_date).strftime("%d/%m/%Y %H:%M:%S")

    @staticmethod
    def obscure(data: bytes) -> bytes:
        """
        Obscurcit les données en les compressant et en les encodant en base64

        Args:
            data (bytes): Les données à obscurcir

        Returns:
            bytes: Les données obscurcies
        """
        return b64e(zlib.compress(data, 9))

    @staticmethod
    def get_package_version(package_name: str) -> str:
        """
        Récupère la version d'un package Python

        Args:
            package_name (str): Le nom du package

        Returns:
            str: La version du package ou un message d'erreur si le package n'est pas trouvé
        """
        try:
            version = importlib.metadata.version(package_name)
            return version
        except importlib.metadata.PackageNotFoundError:
            return f"Package {package_name} not found"